summaryrefslogtreecommitdiffstats
path: root/cobbler/api.py
diff options
context:
space:
mode:
Diffstat (limited to 'cobbler/api.py')
-rw-r--r--cobbler/api.py13
1 files changed, 9 insertions, 4 deletions
diff --git a/cobbler/api.py b/cobbler/api.py
index bd597b2..6268283 100644
--- a/cobbler/api.py
+++ b/cobbler/api.py
@@ -177,12 +177,17 @@ class BootAPI:
statusifier = action_status.BootStatusReport(self._config, mode)
return statusifier.run()
- def import_tree(self,mirror_url,mirror_name):
+ def import_tree(self,mirror_url,mirror_name,network_root=None):
"""
Automatically import a directory tree full of distribution files.
- mirror_url can be a string that represents a path, a user@host syntax for SSH, or an rsync:// address
- """
- importer = action_import.Importer(self, self._config, mirror_url, mirror_name)
+ mirror_url can be a string that represents a path, a user@host
+ syntax for SSH, or an rsync:// address. If mirror_url is a
+ filesystem path and mirroring is not desired, set network_root
+ to something like "nfs://path/to/mirror_url/root"
+ """
+ importer = action_import.Importer(
+ self, self._config, mirror_url, mirror_name, network_root
+ )
return importer.run()
def serialize(self):